#[sys_enum]Expand description
Applies platform config to an enum and verifies trait bounds at compile time.
Use traits(Trait1, Trait2) to ensure the type satisfies these bounds on the target platform.
#[sys_enum]Applies platform config to an enum and verifies trait bounds at compile time.
Use traits(Trait1, Trait2) to ensure the type satisfies these bounds on the target platform.